@@ -7,6 +7,7 @@
 
 """ Implementation for HTTP upload method. """
 
+import contextlib
 import getpass
 from http.client import HTTPConnection
 import os
@@ -84,10 +85,8 @@ class AuthHandlerHackAround:
 
     def get_auth_headers(self):
         for ah in self.authhandlers:
-            try:
+            with contextlib.suppress(ValueError):
                 ah.http_error_401(self, None, 401, None, self.response_headers)
-            except ValueError:
-                pass
         if self.headers:
             return self.headers
         return self.headers
