@@ -1297,7 +1297,7 @@ class get_fqdn_for_host_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(get_fqdn_for_host_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         set_config(self, 'exist-simple')
@@ -1397,7 +1397,7 @@ class get_port_for_host_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(get_port_for_host_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         set_config(self, 'exist-simple')
