@@ -168,7 +168,7 @@ def patch_getpass_getpass(testcase):
     testcase.addCleanup(func_patcher.stop)
 
 
-class upload_TestCase(
+class upload_BaseTestCase(
         testscenarios.WithScenarios,
         testtools.TestCase):
     """ Base for test cases for method modules `upload` functions. """
@@ -252,13 +252,13 @@ class upload_TestCase(
         return command_args
 
 
-class local_upload_TestCase(upload_TestCase):
+class local_upload_TestCase(upload_BaseTestCase):
     """ Test cases for `methods.local.upload` function. """
 
     scenarios = testscenarios.multiply_scenarios(
-            upload_TestCase.incoming_scenarios,
-            upload_TestCase.files_scenarios,
-            upload_TestCase.check_call_success_scenarios)
+            upload_BaseTestCase.incoming_scenarios,
+            upload_BaseTestCase.files_scenarios,
+            upload_BaseTestCase.check_call_success_scenarios)
 
     command_file_path = os.path.join("/usr/bin", "install")
 
@@ -345,7 +345,7 @@ class local_upload_TestCase(upload_TestCase):
         sys.exit.assert_called_with(EXIT_STATUS_FAILURE)
 
 
-class ftp_upload_TestCase(upload_TestCase):
+class ftp_upload_TestCase(upload_BaseTestCase):
     """ Test cases for `methods.ftp.upload` function. """
 
     scenarios = NotImplemented
@@ -415,8 +415,8 @@ class ftp_upload_NormalFilesTestCase(ftp_upload_TestCase):
             ]
 
     scenarios = testscenarios.multiply_scenarios(
-            upload_TestCase.incoming_scenarios,
-            upload_TestCase.files_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
+            upload_BaseTestCase.files_scenarios,
             login_scenarios, ftp_client_scenarios)
 
     def test_emits_debug_message_for_connect(self):
@@ -619,11 +619,11 @@ class ftp_upload_ErrorTestCase(ftp_upload_TestCase):
 
     files_scenarios = list(
             (scenario_name, scenario) for (scenario_name, scenario)
-            in upload_TestCase.files_scenarios
+            in upload_BaseTestCase.files_scenarios
             if scenario['paths_to_upload'])
 
     scenarios = testscenarios.multiply_scenarios(
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             files_scenarios,
             login_scenarios, ftp_client_scenarios, progress_scenarios)
 
@@ -773,8 +773,8 @@ class ftp_upload_ProgressTestCase(ftp_upload_TestCase):
             ]
 
     scenarios = testscenarios.multiply_scenarios(
-            upload_TestCase.incoming_scenarios,
-            upload_TestCase.files_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
+            upload_BaseTestCase.files_scenarios,
             login_scenarios, ftp_client_scenarios, progress_scenarios)
 
     def test_calls_storbinary_with_filewithprogress(self):
@@ -897,7 +897,7 @@ def make_mock_httpresponse(
     return response
 
 
-class http_upload_TestCase(upload_TestCase):
+class http_upload_TestCase(upload_BaseTestCase):
     """ Base for test cases for `methods.http.upload` function. """
 
     scenarios = NotImplemented
@@ -1043,16 +1043,16 @@ class http_upload_SuccessTestCase(http_upload_TestCase):
                 }),
             ]
 
-    incoming_scenarios = list(upload_TestCase.incoming_scenarios)
+    incoming_scenarios = list(upload_BaseTestCase.incoming_scenarios)
     for (scenario_name, scenario) in incoming_scenarios:
         scenario['expected_url_path_prefix'] = os.path.join(
                 os.path.sep, scenario['incoming_path'])
     del scenario_name, scenario
 
     scenarios = testscenarios.multiply_scenarios(
-            upload_TestCase.files_scenarios,
+            upload_BaseTestCase.files_scenarios,
             size_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             http_upload_TestCase.protocol_scenarios,
             http_upload_TestCase.login_scenarios,
             response_scenarios)
@@ -1096,7 +1096,7 @@ class http_upload_ProgressTestCase(http_upload_TestCase):
 
     files_scenarios = list(
             (scenario_name, scenario) for (scenario_name, scenario)
-            in upload_TestCase.files_scenarios
+            in upload_BaseTestCase.files_scenarios
             if scenario['paths_to_upload'])
 
     response_scenarios = [
@@ -1124,7 +1124,7 @@ class http_upload_ProgressTestCase(http_upload_TestCase):
     scenarios = testscenarios.multiply_scenarios(
             files_scenarios,
             progress_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             http_upload_TestCase.protocol_scenarios,
             http_upload_TestCase.login_scenarios,
             response_scenarios)
@@ -1150,7 +1150,7 @@ class http_upload_UnknownProtocolTestCase(http_upload_TestCase):
 
     files_scenarios = list(
             (scenario_name, scenario) for (scenario_name, scenario)
-            in upload_TestCase.files_scenarios
+            in upload_BaseTestCase.files_scenarios
             if scenario['paths_to_upload'])
 
     protocol_scenarios = [
@@ -1168,7 +1168,7 @@ class http_upload_UnknownProtocolTestCase(http_upload_TestCase):
 
     scenarios = testscenarios.multiply_scenarios(
             files_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             protocol_scenarios,
             http_upload_TestCase.login_scenarios,
             response_scenarios)
@@ -1192,7 +1192,7 @@ class http_upload_FileStatFailureTestCase(http_upload_TestCase):
 
     files_scenarios = list(
             (scenario_name, scenario) for (scenario_name, scenario)
-            in upload_TestCase.files_scenarios
+            in upload_BaseTestCase.files_scenarios
             if scenario['paths_to_upload'])
 
     os_stat_scenarios = [
@@ -1213,7 +1213,7 @@ class http_upload_FileStatFailureTestCase(http_upload_TestCase):
     scenarios = testscenarios.multiply_scenarios(
             files_scenarios,
             os_stat_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             http_upload_TestCase.protocol_scenarios,
             http_upload_TestCase.login_scenarios,
             response_scenarios)
@@ -1239,7 +1239,7 @@ class http_upload_ResponseErrorTestCase(http_upload_TestCase):
 
     files_scenarios = list(
             (scenario_name, scenario) for (scenario_name, scenario)
-            in upload_TestCase.files_scenarios
+            in upload_BaseTestCase.files_scenarios
             if scenario['paths_to_upload'])
 
     response_scenarios = [
@@ -1303,7 +1303,7 @@ class http_upload_ResponseErrorTestCase(http_upload_TestCase):
 
     scenarios = testscenarios.multiply_scenarios(
             files_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             http_upload_TestCase.protocol_scenarios,
             http_upload_TestCase.login_scenarios,
             response_scenarios)
@@ -1358,7 +1358,7 @@ class http_upload_ResponseUnauthorizedTestCase(http_upload_TestCase):
 
     files_scenarios = list(
             (scenario_name, scenario) for (scenario_name, scenario)
-            in upload_TestCase.files_scenarios
+            in upload_BaseTestCase.files_scenarios
             if scenario['paths_to_upload'])
 
     response_scenarios = [
@@ -1387,7 +1387,7 @@ class http_upload_ResponseUnauthorizedTestCase(http_upload_TestCase):
 
     scenarios = testscenarios.multiply_scenarios(
             files_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             http_upload_TestCase.protocol_scenarios,
             http_upload_TestCase.login_scenarios,
             response_scenarios)
@@ -1414,7 +1414,7 @@ def make_remote_spec(username, host, dir_path):
     return remote_spec
 
 
-class ssh_channel_upload_TestCase(upload_TestCase):
+class ssh_channel_upload_TestCase(upload_BaseTestCase):
     """ Base for test cases for upload over SSH channel. """
 
     function_to_test = NotImplemented
@@ -1549,8 +1549,8 @@ class scp_upload_ScpTestCase(scp_upload_TestCase):
             ]
 
     scenarios = testscenarios.multiply_scenarios(
-            upload_TestCase.files_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.files_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             ssh_channel_upload_TestCase.login_scenarios,
             ssh_channel_upload_TestCase.stat_mode_scenarios,
             compress_scenarios,
@@ -1597,7 +1597,7 @@ class scp_upload_ChmodTestCase(scp_upload_TestCase):
 
     files_scenarios = list(
             (scenario_name, scenario) for (scenario_name, scenario)
-            in upload_TestCase.files_scenarios
+            in upload_BaseTestCase.files_scenarios
             if scenario['paths_to_upload'])
 
     stat_mode_scenarios = list(
@@ -1614,7 +1614,7 @@ class scp_upload_ChmodTestCase(scp_upload_TestCase):
 
     scenarios = testscenarios.multiply_scenarios(
             files_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             ssh_channel_upload_TestCase.login_scenarios,
             stat_mode_scenarios,
             compress_scenarios,
@@ -1658,8 +1658,8 @@ class rsync_upload_TestCase(ssh_channel_upload_TestCase):
     function_to_test = staticmethod(dput.methods.rsync.upload)
 
     scenarios = testscenarios.multiply_scenarios(
-            upload_TestCase.files_scenarios,
-            upload_TestCase.incoming_scenarios,
+            upload_BaseTestCase.files_scenarios,
+            upload_BaseTestCase.incoming_scenarios,
             ssh_channel_upload_TestCase.login_scenarios,
             ssh_channel_upload_TestCase.stat_mode_scenarios)
 
